@@ -231,7 +231,7 @@ void FcitxKeyLabelWidget::setShortcutShow(bool flag)
             label->show();
         }
         setMaximumWidth(w);
-        setFocus();
+
     } else {
         for (FcitxKeyLabel *label : m_list) {
             label->hide();
@@ -242,7 +242,7 @@ void FcitxKeyLabelWidget::setShortcutShow(bool flag)
         m_keyEdit->clear();
         setMaximumWidth(9999);
     }
-    //update();
+    update();
 }
 
 bool FcitxKeyLabelWidget::checkNewKey(bool isRelease)
@@ -321,8 +321,6 @@ FcitxKeySettingsItem::FcitxKeySettingsItem(const QString &text, const QStringLis
     setFixedHeight(48);
     setAccessibleName(text);
     setLayout(m_hLayout);
-    setTabOrder(m_keyWidget, m_label);
-    m_label->setFocusPolicy(Qt::TabFocus);
     connect(m_keyWidget, &FcitxKeyLabelWidget::editedFinish, this, &FcitxKeySettingsItem::editedFinish);
     connect(m_keyWidget, &FcitxKeyLabelWidget::shortCutError, this, &FcitxKeySettingsItem::doShortCutError);
 }
@@ -435,7 +433,6 @@ FcitxHotKeySettingsItem::FcitxHotKeySettingsItem(const QString &text, const QStr
     setFixedHeight(48);
     setAccessibleName(text);
     setLayout(m_hLayout);
-    setTabOrder(m_keyWidget, m_label);
     connect(m_keyWidget, &FcitxKeyLabelWidget::editedFinish, this, &FcitxHotKeySettingsItem::editedFinish);
     connect(m_keyWidget, &FcitxKeyLabelWidget::shortCutError, this, &FcitxHotKeySettingsItem::doShortCutError);
 }
