@@ -39,10 +39,9 @@
 
 class QCheckBox;
 class QVBoxLayout;
-class QGSettings;
 class QStandardItemModel;
 struct _FcitxConfigFileDesc;
-class QHBoxLayout;
+
 class QTabWidget;
 namespace dcc_fcitx_configtool {
 namespace widgets {
@@ -109,16 +108,6 @@ private:
      */
     void loadFile();
 
-    /**
-     *@brief 将界面控件绑定到gsetting设置
-     */
-    void bindGsettings(const QString &gsettingsName, QLayout *layout);
-
-    /**
-     *@brief 将界面控件绑定到gsetting设置
-     */
-    void bindGsettings(const QString &gsettingsName, QWidget *w);
-
 private slots:
     /**
      *@brief 界面风格改变
@@ -143,7 +132,6 @@ private:
     AddonSelector *m_addonSelector;
     bool m_isSelfSend {false};
     QList<dcc_fcitx_configtool::widgets::FcitxCheckBoxSettingsItem *> m_addonsList;
-    QGSettings *m_gsetting;
 };
 
 /**
@@ -178,7 +166,7 @@ signals:
     void pressed(bool isHidden);
 
 private:
-    bool m_hide{true};
+    bool m_hide{false};
     QString m_originText;
 };
 
