@@ -4,17 +4,17 @@
 <context>
     <name>Fcitx::AdvancedSettingWidget</name>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="105"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="104"/>
         <source>Global Config</source>
         <translation>Globale Konfiguration</translation>
     </message>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="108"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="107"/>
         <source>Add-ons</source>
         <translation>Add-Ons</translation>
     </message>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="391"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="241"/>
         <source>None</source>
         <translation>Keine</translation>
     </message>
@@ -106,45 +106,45 @@
     <name>IMSettingWindow</name>
     <message>
         <location filename="../src/window/imsettingwindow.cpp" line="115"/>
-        <source>Scroll between input methods</source>
-        <translation type="unfinished"></translation>
+        <source>Switch input methods</source>
+        <translation>Eingabemethoden wechseln</translation>
     </message>
     <message>
         <location filename="../src/window/imsettingwindow.cpp" line="119"/>
-        <source>Switch between the current/first input method</source>
-        <translation type="unfinished"></translation>
+        <source>Switch to the first input method</source>
+        <translation>Eingabemethode wechseln</translation>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="122"/>
-        <location filename="../src/window/imsettingwindow.cpp" line="125"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="121"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="124"/>
         <source>Restore Defaults</source>
         <translation>Standardeinstellungen wiederherstellen</translation>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="129"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="128"/>
         <source>Advanced Settings</source>
         <translation>Erweiterte Einstellungen</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="139"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="138"/>
         <source>Manage Input Methods</source>
         <translation>Eingabemethoden verwalten</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="149"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="148"/>
         <source>Shortcuts</source>
         <translation>Tastenkürzel</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="166"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="165"/>
         <source>Add Input Method</source>
-        <translation>Eingabemethode hinzufügen</translation>
+        <translation type="unfinished">Eingabemethode hinzufügen</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
@@ -152,8 +152,8 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="585"/>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="637"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="606"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="658"/>
         <source>None</source>
         <translation>Keine</translation>
     </message>
@@ -161,7 +161,7 @@
 <context>
     <name>dcc_fcitx_configtool::widgets::FcitxCheckBoxSettingsItem</name>
     <message>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="599"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="596"/>
         <source>Configure</source>
         <translation>Konfigurieren</translation>
     </message>
